﻿#include "StdAfx.h"
#include "SettingGeneral.h"
#include "UIMenu.h"
#include "main_frame.hpp"
#include "NeMessengerDlg.h"
#include "CommonFunction.h"

LPCTSTR str_languageArray[5][3] = {{_T("선택하신 언어로 변경하려면 Ntalk을 재실행해야 합니다. 지금 재실행하시겠습니까?"), _T("예"), _T("아니요")}, 
								{_T("You must restart Ntalk for the language changes to take effect. nDo you want to restart it now?"), _T("Yes"), _T("No")}, 
								{_T("選択した言語に変更するには、Ntalkを再実行する必要があります。今、再実行しますか?"), _T("はい"), _T("いいえ")}, 
								{_T("必須重啟Ntalk才能使語言變更生效，要現在重啟嗎？"), _T("是 "), _T("不是")},
								{_T("必须重启Ntalk才能使语言变更生效，要现在重启吗？"), _T("是 "), _T("不是")}};

CSettingGeneral::CSettingGeneral()
{
	CreateControl();
}

CSettingGeneral::~CSettingGeneral()
{
	
}

void CSettingGeneral::CreateControl()
{
	CDialogBuilder builder;
	CContainerUI* pContainerUI = static_cast<CContainerUI*>(builder.Create(_T("setting_general.xml"), (UINT)0));
	if( pContainerUI != NULL ) 
	{
		this->Add(pContainerUI);
	}
	else 
	{
		this->RemoveAll();
		return;
	}
}

void CSettingGeneral::InitControl()
{
	CString str;
	str.LoadString(IDS_STRING406);
	CLabelUI* label_general = static_cast<CLabelUI*>(m_pManager->FindControl(_T("label_general")));
	label_general->SetText(str);

	str.LoadString(IDS_STRING241);
	CCheckBoxUI* check_auto_login = static_cast<CCheckBoxUI*>(m_pManager->FindControl(_T("check_auto_login")));
	check_auto_login->SetText(str);
	check_auto_login->SetCheck(GET_CONFIG()->GetAutoLogin());

	str.LoadString(IDS_STRING409);
	CCheckBoxUI* check_auto_start = static_cast<CCheckBoxUI*>(m_pManager->FindControl(_T("check_auto_start")));
	check_auto_start->SetText(str);
	check_auto_start->SetCheck(GET_CONFIG()->GetAutoStart());

	str.LoadString(IDS_STRING407);
	CTextUI* text_language = static_cast<CTextUI*>(m_pManager->FindControl(_T("text_language")));
	text_language->SetText(str);
	InitLanguage();

	str.LoadString(IDS_STRING408);
	CTextUI* text_time_zone = static_cast<CTextUI*>(m_pManager->FindControl(_T("text_time_zone")));
	text_time_zone->SetText(str);
	InitTimeZone();

	str.LoadString(IDS_STRING423);
	CTextUI* text_file_path = static_cast<CTextUI*>(m_pManager->FindControl(_T("text_file_path")));
	text_file_path->SetText(str);

	CEditUI* edit_file_path = static_cast<CEditUI*>(m_pManager->FindControl(_T("edit_file_path")));
	edit_file_path->SetText(GET_CONFIG()->GetRecvFolder());
	str.LoadString(IDS_STRING714);
	CButtonUI* btn_choose = static_cast<CButtonUI*>(m_pManager->FindControl(_T("btn_choose")));
	btn_choose->SetText(str);

	// modify layout of 'receive file path' for English and Japanese
	if(g_stNtalkInfo.nLang == NTALK_LANG_JAPANESE || g_stNtalkInfo.nLang == NTALK_LANG_ENGLISH)
	{
		CLabelUI* label_file_path_top = static_cast<CLabelUI*>(m_pManager->FindControl(_T("label_file_path_top")));
		label_file_path_top->SetFixedHeight(20);

		//CTextUI* text_file_path = static_cast<CTextUI*>(m_pManager->FindControl(_T("text_file_path")));
		text_file_path->SetFixedHeight(24);

		CLabelUI* label_file_path_bottom = static_cast<CLabelUI*>(m_pManager->FindControl(_T("label_file_path_bottom")));
		label_file_path_bottom->SetFixedHeight(20);
	}
}

bool CSettingGeneral::DoApply()
{
	CCheckBoxUI* check_auto_login = static_cast<CCheckBoxUI*>(m_pManager->FindControl(_T("check_auto_login")));
	GET_CONFIG()->SetAutoLogin(check_auto_login->GetCheck()?1:0);

	CCheckBoxUI* check_auto_start = static_cast<CCheckBoxUI*>(m_pManager->FindControl(_T("check_auto_start")));
	GET_CONFIG()->SetAutoStart(check_auto_start->GetCheck()?1:0);

	CComboExUI* combo_language = static_cast<CComboExUI*>(m_pManager->FindControl(_T("combo_language")));
	GET_CONFIG()->SetLanguage(combo_language->GetCurSel());

	CComboExUI* combo_time_zone = static_cast<CComboExUI*>(m_pManager->FindControl(_T("combo_time_zone")));
	GET_CONFIG()->SetGMT(combo_time_zone->GetCurSel());

	CEditUI* edit_file_path = static_cast<CEditUI*>(m_pManager->FindControl(_T("edit_file_path")));
	GET_CONFIG()->SetRecvFolder(edit_file_path->GetText().GetData());
	return true;
}

void CSettingGeneral::NotifyItemSelect(TNotifyUI& msg)
{
	if(msg.pSender->GetName() == _T("combo_language"))
	{
		CComboExUI* combo_language = static_cast<CComboExUI*>(m_pManager->FindControl(_T("combo_language")));

		if(combo_language->GetCurSel() != GET_CONFIG()->GetLanguage())
		{
			int nLanSet = combo_language->GetCurSel();

			if (nLanSet >= 0 && nLanSet < 5 && NMessageBox(CWnd::FromHandle(m_pManager->GetPaintWindow()), str_languageArray[nLanSet][0], _T("Ntalk Biz"), 
				MB_YESNO, FALSE, _T(""), _T(""), FALSE,
				str_languageArray[nLanSet][1], str_languageArray[nLanSet][2]) == IDYES)
			{
				::PostMessage(GET_MESSENGER_DLG()->GetSafeHwnd(), MSG_RESTART_APP, 0, 0);
			}
		}
	}
	else if(msg.pSender->GetName() == _T("combo_time_zone"))
	{
		//CComboExUI* combo_time_zone = static_cast<CComboExUI*>(m_pManager->FindControl(_T("combo_time_zone")));
		//GET_CONFIG()->SetGMT(combo_time_zone->GetCurSel());
	}
}

void CSettingGeneral::NotifyCtrlClick(TNotifyUI& msg)
{
	if(msg.pSender->GetName() == _T("btn_choose"))
	{
        _OnBtnChooseClicked(msg);
	}
    else if(msg.pSender->GetName() == _T("check_auto_login"))
    {
        _OnBtnAutoLoginClicked(msg);
    }
}

void CSettingGeneral::_OnBtnChooseClicked(TNotifyUI& msg)
{
    CString strPath;

    TCHAR szPath[MAX_PATH + 1] = {0,};
    TCHAR szTitle[MAX_PATH + 1] = {0,};
    _tcscpy_s(szTitle, _countof(szTitle), LoadStringFromResource(IDS_STRING423));

    BROWSEINFO BrowseInfo;
    ::ZeroMemory(&BrowseInfo,sizeof(BrowseInfo));

    BrowseInfo.hwndOwner		= m_pManager->GetPaintWindow();
    BrowseInfo.pidlRoot			= NULL;
    BrowseInfo.pszDisplayName	= szPath;
    BrowseInfo.lpszTitle		= szTitle;
    BrowseInfo.ulFlags			= BIF_NEWDIALOGSTYLE;
    BrowseInfo.lParam			= (LPARAM)(LPCTSTR)strPath;

    LPITEMIDLIST lpItemIdList = SHBrowseForFolder(&BrowseInfo);
    if (lpItemIdList)
    {
        CString strInnerPath;
        SHGetPathFromIDList(lpItemIdList,strInnerPath.GetBuffer(1024));
        strInnerPath.ReleaseBuffer();

        CEditUI* edit_file_path = static_cast<CEditUI*>(m_pManager->FindControl(_T("edit_file_path")));
        edit_file_path->SetText(strInnerPath);
    }

}
void CSettingGeneral::_OnBtnAutoLoginClicked(TNotifyUI& msg)
{
    CCheckBoxUI* pCheckAutoLogin = dynamic_cast<CCheckBoxUI*>(msg.pSender);
    ASSERT(pCheckAutoLogin);
    if (pCheckAutoLogin)
    {
        if (!pCheckAutoLogin->GetCheck())   //from false to true
        {
            if(NMessageBox(CWnd::FromHandle(m_pManager->GetPaintWindow()), 
                LoadStringFromResource(IDS_STRING_AUTO_LOGIN_PROMPT), 
                _T("Ntalk biz"), MB_OKCANCEL) == IDCANCEL)
            {
                pCheckAutoLogin->SetCheck(!pCheckAutoLogin->GetCheck());
            }
        }
    }
}

void CSettingGeneral::InitLanguage()
{
	CComboExUI* combo_language = static_cast<CComboExUI*>(m_pManager->FindControl(_T("combo_language")));
	combo_language->RemoveAll();

	CListLabelElementUI* item = NULL;
	CString str;

	for(int i = IDS_STRING401; i <= IDS_STRING405; i++)
	{
		str.LoadString(i);
		item = new CListLabelElementUI();
		item->SetText(str);
		combo_language->Add(item);
	}

	combo_language->SelectItem(GET_CONFIG()->GetLanguage());
}

void CSettingGeneral::InitTimeZone()
{
	CComboExUI* combo_time_zone = static_cast<CComboExUI*>(m_pManager->FindControl(_T("combo_time_zone")));
	combo_time_zone->RemoveAll();

	CListLabelElementUI* item = NULL;
	CString str;

	for(int i = IDS_STRING178; i <= IDS_STRING207; i++)
	{
		str.LoadString(i);
		item = new CListLabelElementUI();
		item->SetText(str);
		combo_time_zone->Add(item);
	}

	str.LoadString(IDS_STRING540);
	item = new CListLabelElementUI();
	item->SetText(str);
	combo_time_zone->Add(item);

	str.LoadString(IDS_STRING208);
	item = new CListLabelElementUI();
	item->SetText(str);
	combo_time_zone->Add(item);

	combo_time_zone->SelectItem(GET_CONFIG()->GetGMT());
}
